pub fn decode_wasm_module(wasm_bytes: &[u8]) -> Result<DecodedModule>Expand description
Decode a WASM binary and extract functions, memory, and data segments
pub fn decode_wasm_module(wasm_bytes: &[u8]) -> Result<DecodedModule>Decode a WASM binary and extract functions, memory, and data segments